﻿using Microsoft.EntityFrameworkCore;
using SushiBarContracts.BindingModels;
using SushiBarContracts.SearchModels;
using SushiBarContracts.StoragesContracts;
using SushiBarContracts.ViewModels;
using SushiBarDatabaseImplement.Models;

namespace SushiBarDatabaseImplement.Implements
{
    public class MessageInfoStorage : IMessageInfoStorage
    {

        public MessageInfoViewModel? GetElement(MessageInfoSearchModel model)
        {
            using var context = new SushiBarDatabase();
            if (model.MessageId != null)
            {
                return context.Messages
                    .FirstOrDefault(x => x.MessageId == model.MessageId)?.GetViewModel;
            }
            return null;
        }

        public List<MessageInfoViewModel> GetFilteredList(MessageInfoSearchModel model)
        {
            using var context = new SushiBarDatabase();
            return context.Messages
                .Where(x => x.ClientId == model.ClientId)
                .Select(x => x.GetViewModel)
                .ToList();
        }

        public List<MessageInfoViewModel> GetFullList()
        {
            using var context = new SushiBarDatabase();
            return context.Messages
                .Select(x => x.GetViewModel)
                .ToList();
        }

        public MessageInfoViewModel? Insert(MessageInfoBindingModel model)
        {
            using var context = new SushiBarDatabase();
            var newMessage = MessageInfo.Create(context, model);
            if (newMessage == null || context.Messages.Any(x => x.MessageId.Equals(model.MessageId)))
            {
                return null;
            }
            context.Messages.Add(newMessage);
            context.SaveChanges();
            return newMessage.GetViewModel;
        }
    }
}
